@@ -1,4 +1,5 @@
 from django.apps import apps
+from django.db.models import ObjectDoesNotExist
 
 
 def get_related_object(scope, field_name):
@@ -8,7 +9,7 @@ def get_related_object(scope, field_name):
     try:
         Model = apps.get_model(scope[field_name]['model'])
         relobj = Model.objects.get(pk=scope[field_name]['pk'])
-    except:
+    except (ObjectDoesNotExist, LookupError):
         relobj = None
     return relobj
 
@@ -20,6 +21,6 @@ def get_related_queryset(scope, field_name):
     try:
         Model = apps.get_model(scope[field_name]['model'])
         queryset = Model.objects.filter(pk__in=scope[field_name]['p_keys'])
-    except:
+    except LookupError:
         queryset = None
     return queryset
